@@ -1,7 +1,7 @@
 package WWW::DistroWatch::ReleaseInfo;
 
 our $DATE = '2015-10-06'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -68,6 +68,8 @@ sub list_distros {
 }
 
 our $distros = do {
+    no warnings 'void';
+    {};
  {
    "0linux"         => "0Linux",
    "2x"             => "2XOS",
@@ -387,6 +389,13 @@ _
             summary => 'Name of distribution, e.g. "mint", "ubuntu", "debian"',
             req => 1,
             pos => 0,
+            completion => sub {
+                require Complete::Util;
+                my %args = @_;
+                Complete::Util::complete_array_elem(
+                    word=>$args{word}, array=>[keys %$distros],
+                );
+            },
         },
         %file_args,
     },
@@ -496,7 +505,7 @@ WWW::DistroWatch::ReleaseInfo - Get information about a distro's releases
 
 =head1 VERSION
 
-This document describes version 0.04 of WWW::DistroWatch::ReleaseInfo (from Perl distribution WWW-DistroWatch-ReleaseInfo), released on 2015-10-06.
+This document describes version 0.05 of WWW::DistroWatch::ReleaseInfo (from Perl distribution WWW-DistroWatch-ReleaseInfo), released on 2015-10-06.
 
 =head1 FUNCTIONS
 
